:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.columns:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

:root {
  --bulma-column-gap: 1.5rem;
}

.column {
  display: block;
  flex-basis: 0;
  flex-grow: 1;
  flex-shrink: 1;
}
.columns.is-mobile > .column.is-narrow {
  flex: none;
  width: unset;
}
.columns.is-mobile > .column.is-full {
  flex: none;
  width: 100%;
}
.columns.is-mobile > .column.is-three-quarters {
  flex: none;
  width: calc(75% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-two-thirds {
  flex: none;
  width: calc(66.6666% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-half {
  flex: none;
  width: calc(50% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-one-third {
  flex: none;
  width: calc(33.3333% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-one-quarter {
  flex: none;
  width: calc(25% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-one-fifth {
  flex: none;
  width: calc(20% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-two-fifths {
  flex: none;
  width: calc(40% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-three-fifths {
  flex: none;
  width: calc(60% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-four-fifths {
  flex: none;
  width: calc(80% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-three-quarters {
  margin-inline-start: 75%;
}
.columns.is-mobile > .column.is-offset-two-thirds {
  margin-inline-start: 66.6666%;
}
.columns.is-mobile > .column.is-offset-half {
  margin-inline-start: 50%;
}
.columns.is-mobile > .column.is-offset-one-third {
  margin-inline-start: 33.3333%;
}
.columns.is-mobile > .column.is-offset-one-quarter {
  margin-inline-start: 25%;
}
.columns.is-mobile > .column.is-offset-one-fifth {
  margin-inline-start: 20%;
}
.columns.is-mobile > .column.is-offset-two-fifths {
  margin-inline-start: 40%;
}
.columns.is-mobile > .column.is-offset-three-fifths {
  margin-inline-start: 60%;
}
.columns.is-mobile > .column.is-offset-four-fifths {
  margin-inline-start: 80%;
}
.columns.is-mobile > .column.is-0 {
  flex: none;
  width: calc(0% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-0 {
  margin-inline-start: 0%;
}
.columns.is-mobile > .column.is-1 {
  flex: none;
  width: calc(8.3333333333% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-1 {
  margin-inline-start: 8.3333333333%;
}
.columns.is-mobile > .column.is-2 {
  flex: none;
  width: calc(16.6666666667% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-2 {
  margin-inline-start: 16.6666666667%;
}
.columns.is-mobile > .column.is-3 {
  flex: none;
  width: calc(25% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-3 {
  margin-inline-start: 25%;
}
.columns.is-mobile > .column.is-4 {
  flex: none;
  width: calc(33.3333333333% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-4 {
  margin-inline-start: 33.3333333333%;
}
.columns.is-mobile > .column.is-5 {
  flex: none;
  width: calc(41.6666666667% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-5 {
  margin-inline-start: 41.6666666667%;
}
.columns.is-mobile > .column.is-6 {
  flex: none;
  width: calc(50% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-6 {
  margin-inline-start: 50%;
}
.columns.is-mobile > .column.is-7 {
  flex: none;
  width: calc(58.3333333333% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-7 {
  margin-inline-start: 58.3333333333%;
}
.columns.is-mobile > .column.is-8 {
  flex: none;
  width: calc(66.6666666667% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-8 {
  margin-inline-start: 66.6666666667%;
}
.columns.is-mobile > .column.is-9 {
  flex: none;
  width: calc(75% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-9 {
  margin-inline-start: 75%;
}
.columns.is-mobile > .column.is-10 {
  flex: none;
  width: calc(83.3333333333% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-10 {
  margin-inline-start: 83.3333333333%;
}
.columns.is-mobile > .column.is-11 {
  flex: none;
  width: calc(91.6666666667% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-11 {
  margin-inline-start: 91.6666666667%;
}
.columns.is-mobile > .column.is-12 {
  flex: none;
  width: calc(100% - var(--bulma-column-gap) / 2);
}
.columns.is-mobile > .column.is-offset-12 {
  margin-inline-start: 100%;
}
@media screen and (max-width: 768px) {
  .column.is-narrow-mobile {
    flex: none;
    width: unset;
  }
  .column.is-full-mobile {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-mobile {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-thirds-mobile {
    flex: none;
    width: calc(66.6666% - var(--bulma-column-gap) / 2);
  }
  .column.is-half-mobile {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-third-mobile {
    flex: none;
    width: calc(33.3333% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-quarter-mobile {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-fifth-mobile {
    flex: none;
    width: calc(20% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-fifths-mobile {
    flex: none;
    width: calc(40% - var(--bulma-column-gap) / 2);
  }
  .column.is-three-fifths-mobile {
    flex: none;
    width: calc(60% - var(--bulma-column-gap) / 2);
  }
  .column.is-four-fifths-mobile {
    flex: none;
    width: calc(80% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-three-quarters-mobile {
    margin-inline-start: 75%;
  }
  .column.is-offset-two-thirds-mobile {
    margin-inline-start: 66.6666%;
  }
  .column.is-offset-half-mobile {
    margin-inline-start: 50%;
  }
  .column.is-offset-one-third-mobile {
    margin-inline-start: 33.3333%;
  }
  .column.is-offset-one-quarter-mobile {
    margin-inline-start: 25%;
  }
  .column.is-offset-one-fifth-mobile {
    margin-inline-start: 20%;
  }
  .column.is-offset-two-fifths-mobile {
    margin-inline-start: 40%;
  }
  .column.is-offset-three-fifths-mobile {
    margin-inline-start: 60%;
  }
  .column.is-offset-four-fifths-mobile {
    margin-inline-start: 80%;
  }
  .column.is-0-mobile {
    flex: none;
    width: calc(0% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-0-mobile {
    margin-inline-start: 0%;
  }
  .column.is-1-mobile {
    flex: none;
    width: calc(8.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-1-mobile {
    margin-inline-start: 8.3333333333%;
  }
  .column.is-2-mobile {
    flex: none;
    width: calc(16.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-2-mobile {
    margin-inline-start: 16.6666666667%;
  }
  .column.is-3-mobile {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-3-mobile {
    margin-inline-start: 25%;
  }
  .column.is-4-mobile {
    flex: none;
    width: calc(33.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-4-mobile {
    margin-inline-start: 33.3333333333%;
  }
  .column.is-5-mobile {
    flex: none;
    width: calc(41.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-5-mobile {
    margin-inline-start: 41.6666666667%;
  }
  .column.is-6-mobile {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-6-mobile {
    margin-inline-start: 50%;
  }
  .column.is-7-mobile {
    flex: none;
    width: calc(58.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-7-mobile {
    margin-inline-start: 58.3333333333%;
  }
  .column.is-8-mobile {
    flex: none;
    width: calc(66.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-8-mobile {
    margin-inline-start: 66.6666666667%;
  }
  .column.is-9-mobile {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-9-mobile {
    margin-inline-start: 75%;
  }
  .column.is-10-mobile {
    flex: none;
    width: calc(83.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-10-mobile {
    margin-inline-start: 83.3333333333%;
  }
  .column.is-11-mobile {
    flex: none;
    width: calc(91.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-11-mobile {
    margin-inline-start: 91.6666666667%;
  }
  .column.is-12-mobile {
    flex: none;
    width: calc(100% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-12-mobile {
    margin-inline-start: 100%;
  }
}
@media screen and (min-width: 769px), print {
  .column.is-narrow, .column.is-narrow-tablet {
    flex: none;
    width: unset;
  }
  .column.is-full, .column.is-full-tablet {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters, .column.is-three-quarters-tablet {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-thirds, .column.is-two-thirds-tablet {
    flex: none;
    width: calc(66.6666% - var(--bulma-column-gap) / 2);
  }
  .column.is-half, .column.is-half-tablet {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-third, .column.is-one-third-tablet {
    flex: none;
    width: calc(33.3333% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-quarter, .column.is-one-quarter-tablet {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-fifth, .column.is-one-fifth-tablet {
    flex: none;
    width: calc(20% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-fifths, .column.is-two-fifths-tablet {
    flex: none;
    width: calc(40% - var(--bulma-column-gap) / 2);
  }
  .column.is-three-fifths, .column.is-three-fifths-tablet {
    flex: none;
    width: calc(60% - var(--bulma-column-gap) / 2);
  }
  .column.is-four-fifths, .column.is-four-fifths-tablet {
    flex: none;
    width: calc(80% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-three-quarters, .column.is-offset-three-quarters-tablet {
    margin-inline-start: 75%;
  }
  .column.is-offset-two-thirds, .column.is-offset-two-thirds-tablet {
    margin-inline-start: 66.6666%;
  }
  .column.is-offset-half, .column.is-offset-half-tablet {
    margin-inline-start: 50%;
  }
  .column.is-offset-one-third, .column.is-offset-one-third-tablet {
    margin-inline-start: 33.3333%;
  }
  .column.is-offset-one-quarter, .column.is-offset-one-quarter-tablet {
    margin-inline-start: 25%;
  }
  .column.is-offset-one-fifth, .column.is-offset-one-fifth-tablet {
    margin-inline-start: 20%;
  }
  .column.is-offset-two-fifths, .column.is-offset-two-fifths-tablet {
    margin-inline-start: 40%;
  }
  .column.is-offset-three-fifths, .column.is-offset-three-fifths-tablet {
    margin-inline-start: 60%;
  }
  .column.is-offset-four-fifths, .column.is-offset-four-fifths-tablet {
    margin-inline-start: 80%;
  }
  .column.is-0, .column.is-0-tablet {
    flex: none;
    width: calc(0% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-0, .column.is-offset-0-tablet {
    margin-inline-start: 0%;
  }
  .column.is-1, .column.is-1-tablet {
    flex: none;
    width: calc(8.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-1, .column.is-offset-1-tablet {
    margin-inline-start: 8.3333333333%;
  }
  .column.is-2, .column.is-2-tablet {
    flex: none;
    width: calc(16.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-2, .column.is-offset-2-tablet {
    margin-inline-start: 16.6666666667%;
  }
  .column.is-3, .column.is-3-tablet {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-3, .column.is-offset-3-tablet {
    margin-inline-start: 25%;
  }
  .column.is-4, .column.is-4-tablet {
    flex: none;
    width: calc(33.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-4, .column.is-offset-4-tablet {
    margin-inline-start: 33.3333333333%;
  }
  .column.is-5, .column.is-5-tablet {
    flex: none;
    width: calc(41.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-5, .column.is-offset-5-tablet {
    margin-inline-start: 41.6666666667%;
  }
  .column.is-6, .column.is-6-tablet {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-6, .column.is-offset-6-tablet {
    margin-inline-start: 50%;
  }
  .column.is-7, .column.is-7-tablet {
    flex: none;
    width: calc(58.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-7, .column.is-offset-7-tablet {
    margin-inline-start: 58.3333333333%;
  }
  .column.is-8, .column.is-8-tablet {
    flex: none;
    width: calc(66.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-8, .column.is-offset-8-tablet {
    margin-inline-start: 66.6666666667%;
  }
  .column.is-9, .column.is-9-tablet {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-9, .column.is-offset-9-tablet {
    margin-inline-start: 75%;
  }
  .column.is-10, .column.is-10-tablet {
    flex: none;
    width: calc(83.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-10, .column.is-offset-10-tablet {
    margin-inline-start: 83.3333333333%;
  }
  .column.is-11, .column.is-11-tablet {
    flex: none;
    width: calc(91.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-11, .column.is-offset-11-tablet {
    margin-inline-start: 91.6666666667%;
  }
  .column.is-12, .column.is-12-tablet {
    flex: none;
    width: calc(100% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-12, .column.is-offset-12-tablet {
    margin-inline-start: 100%;
  }
}
@media screen and (max-width: 1023px) {
  .column.is-narrow-touch {
    flex: none;
    width: unset;
  }
  .column.is-full-touch {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-touch {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-thirds-touch {
    flex: none;
    width: calc(66.6666% - var(--bulma-column-gap) / 2);
  }
  .column.is-half-touch {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-third-touch {
    flex: none;
    width: calc(33.3333% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-quarter-touch {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-fifth-touch {
    flex: none;
    width: calc(20% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-fifths-touch {
    flex: none;
    width: calc(40% - var(--bulma-column-gap) / 2);
  }
  .column.is-three-fifths-touch {
    flex: none;
    width: calc(60% - var(--bulma-column-gap) / 2);
  }
  .column.is-four-fifths-touch {
    flex: none;
    width: calc(80% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-three-quarters-touch {
    margin-inline-start: 75%;
  }
  .column.is-offset-two-thirds-touch {
    margin-inline-start: 66.6666%;
  }
  .column.is-offset-half-touch {
    margin-inline-start: 50%;
  }
  .column.is-offset-one-third-touch {
    margin-inline-start: 33.3333%;
  }
  .column.is-offset-one-quarter-touch {
    margin-inline-start: 25%;
  }
  .column.is-offset-one-fifth-touch {
    margin-inline-start: 20%;
  }
  .column.is-offset-two-fifths-touch {
    margin-inline-start: 40%;
  }
  .column.is-offset-three-fifths-touch {
    margin-inline-start: 60%;
  }
  .column.is-offset-four-fifths-touch {
    margin-inline-start: 80%;
  }
  .column.is-0-touch {
    flex: none;
    width: 0%;
  }
  .column.is-offset-0-touch {
    margin-inline-start: 0%;
  }
  .column.is-1-touch {
    flex: none;
    width: 8.3333333333%;
  }
  .column.is-offset-1-touch {
    margin-inline-start: 8.3333333333%;
  }
  .column.is-2-touch {
    flex: none;
    width: 16.6666666667%;
  }
  .column.is-offset-2-touch {
    margin-inline-start: 16.6666666667%;
  }
  .column.is-3-touch {
    flex: none;
    width: 25%;
  }
  .column.is-offset-3-touch {
    margin-inline-start: 25%;
  }
  .column.is-4-touch {
    flex: none;
    width: 33.3333333333%;
  }
  .column.is-offset-4-touch {
    margin-inline-start: 33.3333333333%;
  }
  .column.is-5-touch {
    flex: none;
    width: 41.6666666667%;
  }
  .column.is-offset-5-touch {
    margin-inline-start: 41.6666666667%;
  }
  .column.is-6-touch {
    flex: none;
    width: 50%;
  }
  .column.is-offset-6-touch {
    margin-inline-start: 50%;
  }
  .column.is-7-touch {
    flex: none;
    width: 58.3333333333%;
  }
  .column.is-offset-7-touch {
    margin-inline-start: 58.3333333333%;
  }
  .column.is-8-touch {
    flex: none;
    width: 66.6666666667%;
  }
  .column.is-offset-8-touch {
    margin-inline-start: 66.6666666667%;
  }
  .column.is-9-touch {
    flex: none;
    width: 75%;
  }
  .column.is-offset-9-touch {
    margin-inline-start: 75%;
  }
  .column.is-10-touch {
    flex: none;
    width: 83.3333333333%;
  }
  .column.is-offset-10-touch {
    margin-inline-start: 83.3333333333%;
  }
  .column.is-11-touch {
    flex: none;
    width: 91.6666666667%;
  }
  .column.is-offset-11-touch {
    margin-inline-start: 91.6666666667%;
  }
  .column.is-12-touch {
    flex: none;
    width: 100%;
  }
  .column.is-offset-12-touch {
    margin-inline-start: 100%;
  }
}
@media screen and (min-width: 1024px) {
  .column.is-narrow-desktop {
    flex: none;
    width: unset;
  }
  .column.is-full-desktop {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-desktop {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-thirds-desktop {
    flex: none;
    width: calc(66.6666% - var(--bulma-column-gap) / 2);
  }
  .column.is-half-desktop {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-third-desktop {
    flex: none;
    width: calc(33.3333% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-quarter-desktop {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-fifth-desktop {
    flex: none;
    width: calc(20% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-fifths-desktop {
    flex: none;
    width: calc(40% - var(--bulma-column-gap) / 2);
  }
  .column.is-three-fifths-desktop {
    flex: none;
    width: calc(60% - var(--bulma-column-gap) / 2);
  }
  .column.is-four-fifths-desktop {
    flex: none;
    width: calc(80% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-three-quarters-desktop {
    margin-inline-start: 75%;
  }
  .column.is-offset-two-thirds-desktop {
    margin-inline-start: 66.6666%;
  }
  .column.is-offset-half-desktop {
    margin-inline-start: 50%;
  }
  .column.is-offset-one-third-desktop {
    margin-inline-start: 33.3333%;
  }
  .column.is-offset-one-quarter-desktop {
    margin-inline-start: 25%;
  }
  .column.is-offset-one-fifth-desktop {
    margin-inline-start: 20%;
  }
  .column.is-offset-two-fifths-desktop {
    margin-inline-start: 40%;
  }
  .column.is-offset-three-fifths-desktop {
    margin-inline-start: 60%;
  }
  .column.is-offset-four-fifths-desktop {
    margin-inline-start: 80%;
  }
  .column.is-0-desktop {
    flex: none;
    width: calc(0% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-0-desktop {
    margin-inline-start: 0%;
  }
  .column.is-1-desktop {
    flex: none;
    width: calc(8.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-1-desktop {
    margin-inline-start: 8.3333333333%;
  }
  .column.is-2-desktop {
    flex: none;
    width: calc(16.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-2-desktop {
    margin-inline-start: 16.6666666667%;
  }
  .column.is-3-desktop {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-3-desktop {
    margin-inline-start: 25%;
  }
  .column.is-4-desktop {
    flex: none;
    width: calc(33.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-4-desktop {
    margin-inline-start: 33.3333333333%;
  }
  .column.is-5-desktop {
    flex: none;
    width: calc(41.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-5-desktop {
    margin-inline-start: 41.6666666667%;
  }
  .column.is-6-desktop {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-6-desktop {
    margin-inline-start: 50%;
  }
  .column.is-7-desktop {
    flex: none;
    width: calc(58.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-7-desktop {
    margin-inline-start: 58.3333333333%;
  }
  .column.is-8-desktop {
    flex: none;
    width: calc(66.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-8-desktop {
    margin-inline-start: 66.6666666667%;
  }
  .column.is-9-desktop {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-9-desktop {
    margin-inline-start: 75%;
  }
  .column.is-10-desktop {
    flex: none;
    width: calc(83.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-10-desktop {
    margin-inline-start: 83.3333333333%;
  }
  .column.is-11-desktop {
    flex: none;
    width: calc(91.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-11-desktop {
    margin-inline-start: 91.6666666667%;
  }
  .column.is-12-desktop {
    flex: none;
    width: calc(100% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-12-desktop {
    margin-inline-start: 100%;
  }
}
@media screen and (min-width: 1216px) {
  .column.is-narrow-widescreen {
    flex: none;
    width: unset;
  }
  .column.is-full-widescreen {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-widescreen {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-thirds-widescreen {
    flex: none;
    width: calc(66.6666% - var(--bulma-column-gap) / 2);
  }
  .column.is-half-widescreen {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-third-widescreen {
    flex: none;
    width: calc(33.3333% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-quarter-widescreen {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-fifth-widescreen {
    flex: none;
    width: calc(20% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-fifths-widescreen {
    flex: none;
    width: calc(40% - var(--bulma-column-gap) / 2);
  }
  .column.is-three-fifths-widescreen {
    flex: none;
    width: calc(60% - var(--bulma-column-gap) / 2);
  }
  .column.is-four-fifths-widescreen {
    flex: none;
    width: calc(80% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-three-quarters-widescreen {
    margin-inline-start: 75%;
  }
  .column.is-offset-two-thirds-widescreen {
    margin-inline-start: 66.6666%;
  }
  .column.is-offset-half-widescreen {
    margin-inline-start: 50%;
  }
  .column.is-offset-one-third-widescreen {
    margin-inline-start: 33.3333%;
  }
  .column.is-offset-one-quarter-widescreen {
    margin-inline-start: 25%;
  }
  .column.is-offset-one-fifth-widescreen {
    margin-inline-start: 20%;
  }
  .column.is-offset-two-fifths-widescreen {
    margin-inline-start: 40%;
  }
  .column.is-offset-three-fifths-widescreen {
    margin-inline-start: 60%;
  }
  .column.is-offset-four-fifths-widescreen {
    margin-inline-start: 80%;
  }
  .column.is-0-widescreen {
    flex: none;
    width: calc(0% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-0-widescreen {
    margin-inline-start: 0%;
  }
  .column.is-1-widescreen {
    flex: none;
    width: calc(8.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-1-widescreen {
    margin-inline-start: 8.3333333333%;
  }
  .column.is-2-widescreen {
    flex: none;
    width: calc(16.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-2-widescreen {
    margin-inline-start: 16.6666666667%;
  }
  .column.is-3-widescreen {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-3-widescreen {
    margin-inline-start: 25%;
  }
  .column.is-4-widescreen {
    flex: none;
    width: calc(33.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-4-widescreen {
    margin-inline-start: 33.3333333333%;
  }
  .column.is-5-widescreen {
    flex: none;
    width: calc(41.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-5-widescreen {
    margin-inline-start: 41.6666666667%;
  }
  .column.is-6-widescreen {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-6-widescreen {
    margin-inline-start: 50%;
  }
  .column.is-7-widescreen {
    flex: none;
    width: calc(58.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-7-widescreen {
    margin-inline-start: 58.3333333333%;
  }
  .column.is-8-widescreen {
    flex: none;
    width: calc(66.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-8-widescreen {
    margin-inline-start: 66.6666666667%;
  }
  .column.is-9-widescreen {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-9-widescreen {
    margin-inline-start: 75%;
  }
  .column.is-10-widescreen {
    flex: none;
    width: calc(83.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-10-widescreen {
    margin-inline-start: 83.3333333333%;
  }
  .column.is-11-widescreen {
    flex: none;
    width: calc(91.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-11-widescreen {
    margin-inline-start: 91.6666666667%;
  }
  .column.is-12-widescreen {
    flex: none;
    width: calc(100% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-12-widescreen {
    margin-inline-start: 100%;
  }
}
@media screen and (min-width: 1408px) {
  .column.is-narrow-fullhd {
    flex: none;
    width: unset;
  }
  .column.is-full-fullhd {
    flex: none;
    width: 100%;
  }
  .column.is-three-quarters-fullhd {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-thirds-fullhd {
    flex: none;
    width: calc(66.6666% - var(--bulma-column-gap) / 2);
  }
  .column.is-half-fullhd {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-third-fullhd {
    flex: none;
    width: calc(33.3333% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-quarter-fullhd {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-one-fifth-fullhd {
    flex: none;
    width: calc(20% - var(--bulma-column-gap) / 2);
  }
  .column.is-two-fifths-fullhd {
    flex: none;
    width: calc(40% - var(--bulma-column-gap) / 2);
  }
  .column.is-three-fifths-fullhd {
    flex: none;
    width: calc(60% - var(--bulma-column-gap) / 2);
  }
  .column.is-four-fifths-fullhd {
    flex: none;
    width: calc(80% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-three-quarters-fullhd {
    margin-inline-start: 75%;
  }
  .column.is-offset-two-thirds-fullhd {
    margin-inline-start: 66.6666%;
  }
  .column.is-offset-half-fullhd {
    margin-inline-start: 50%;
  }
  .column.is-offset-one-third-fullhd {
    margin-inline-start: 33.3333%;
  }
  .column.is-offset-one-quarter-fullhd {
    margin-inline-start: 25%;
  }
  .column.is-offset-one-fifth-fullhd {
    margin-inline-start: 20%;
  }
  .column.is-offset-two-fifths-fullhd {
    margin-inline-start: 40%;
  }
  .column.is-offset-three-fifths-fullhd {
    margin-inline-start: 60%;
  }
  .column.is-offset-four-fifths-fullhd {
    margin-inline-start: 80%;
  }
  .column.is-0-fullhd {
    flex: none;
    width: calc(0% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-0-fullhd {
    margin-inline-start: 0%;
  }
  .column.is-1-fullhd {
    flex: none;
    width: calc(8.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-1-fullhd {
    margin-inline-start: 8.3333333333%;
  }
  .column.is-2-fullhd {
    flex: none;
    width: calc(16.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-2-fullhd {
    margin-inline-start: 16.6666666667%;
  }
  .column.is-3-fullhd {
    flex: none;
    width: calc(25% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-3-fullhd {
    margin-inline-start: 25%;
  }
  .column.is-4-fullhd {
    flex: none;
    width: calc(33.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-4-fullhd {
    margin-inline-start: 33.3333333333%;
  }
  .column.is-5-fullhd {
    flex: none;
    width: calc(41.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-5-fullhd {
    margin-inline-start: 41.6666666667%;
  }
  .column.is-6-fullhd {
    flex: none;
    width: calc(50% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-6-fullhd {
    margin-inline-start: 50%;
  }
  .column.is-7-fullhd {
    flex: none;
    width: calc(58.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-7-fullhd {
    margin-inline-start: 58.3333333333%;
  }
  .column.is-8-fullhd {
    flex: none;
    width: calc(66.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-8-fullhd {
    margin-inline-start: 66.6666666667%;
  }
  .column.is-9-fullhd {
    flex: none;
    width: calc(75% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-9-fullhd {
    margin-inline-start: 75%;
  }
  .column.is-10-fullhd {
    flex: none;
    width: calc(83.3333333333% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-10-fullhd {
    margin-inline-start: 83.3333333333%;
  }
  .column.is-11-fullhd {
    flex: none;
    width: calc(91.6666666667% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-11-fullhd {
    margin-inline-start: 91.6666666667%;
  }
  .column.is-12-fullhd {
    flex: none;
    width: calc(100% - var(--bulma-column-gap) / 2);
  }
  .column.is-offset-12-fullhd {
    margin-inline-start: 100%;
  }
}

.columns {
  gap: var(--bulma-column-gap);
}
.columns.is-centered {
  justify-content: center;
}
.columns.is-gapless {
  gap: 0;
}
.columns.is-mobile {
  display: flex;
}
.columns.is-multiline {
  flex-wrap: wrap;
}
.columns.is-vcentered {
  align-items: center;
}
@media screen and (min-width: 769px), print {
  .columns:not(.is-desktop) {
    display: flex;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-desktop {
    display: flex;
  }
}
.columns.is-variable.is-0 {
  --bulma-column-gap: 0rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-0-mobile {
    --bulma-column-gap: 0rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-0-tablet {
    --bulma-column-gap: 0rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-0-tablet-only {
    --bulma-column-gap: 0rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-0-touch {
    --bulma-column-gap: 0rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-0-desktop {
    --bulma-column-gap: 0rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-0-desktop-only {
    --bulma-column-gap: 0rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-0-widescreen {
    --bulma-column-gap: 0rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-0-widescreen-only {
    --bulma-column-gap: 0rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-0-fullhd {
    --bulma-column-gap: 0rem;
  }
}
.columns.is-variable.is-1 {
  --bulma-column-gap: 0.25rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-1-mobile {
    --bulma-column-gap: 0.25rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-1-tablet {
    --bulma-column-gap: 0.25rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-1-tablet-only {
    --bulma-column-gap: 0.25rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-1-touch {
    --bulma-column-gap: 0.25rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-1-desktop {
    --bulma-column-gap: 0.25rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-1-desktop-only {
    --bulma-column-gap: 0.25rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-1-widescreen {
    --bulma-column-gap: 0.25rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-1-widescreen-only {
    --bulma-column-gap: 0.25rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-1-fullhd {
    --bulma-column-gap: 0.25rem;
  }
}
.columns.is-variable.is-2 {
  --bulma-column-gap: 0.5rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-2-mobile {
    --bulma-column-gap: 0.5rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-2-tablet {
    --bulma-column-gap: 0.5rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-2-tablet-only {
    --bulma-column-gap: 0.5rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-2-touch {
    --bulma-column-gap: 0.5rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-2-desktop {
    --bulma-column-gap: 0.5rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-2-desktop-only {
    --bulma-column-gap: 0.5rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-2-widescreen {
    --bulma-column-gap: 0.5rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-2-widescreen-only {
    --bulma-column-gap: 0.5rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-2-fullhd {
    --bulma-column-gap: 0.5rem;
  }
}
.columns.is-variable.is-3 {
  --bulma-column-gap: 0.75rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-3-mobile {
    --bulma-column-gap: 0.75rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-3-tablet {
    --bulma-column-gap: 0.75rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-3-tablet-only {
    --bulma-column-gap: 0.75rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-3-touch {
    --bulma-column-gap: 0.75rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-3-desktop {
    --bulma-column-gap: 0.75rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-3-desktop-only {
    --bulma-column-gap: 0.75rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-3-widescreen {
    --bulma-column-gap: 0.75rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-3-widescreen-only {
    --bulma-column-gap: 0.75rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-3-fullhd {
    --bulma-column-gap: 0.75rem;
  }
}
.columns.is-variable.is-4 {
  --bulma-column-gap: 1rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-4-mobile {
    --bulma-column-gap: 1rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-4-tablet {
    --bulma-column-gap: 1rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-4-tablet-only {
    --bulma-column-gap: 1rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-4-touch {
    --bulma-column-gap: 1rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-4-desktop {
    --bulma-column-gap: 1rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-4-desktop-only {
    --bulma-column-gap: 1rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-4-widescreen {
    --bulma-column-gap: 1rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-4-widescreen-only {
    --bulma-column-gap: 1rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-4-fullhd {
    --bulma-column-gap: 1rem;
  }
}
.columns.is-variable.is-5 {
  --bulma-column-gap: 1.25rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-5-mobile {
    --bulma-column-gap: 1.25rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-5-tablet {
    --bulma-column-gap: 1.25rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-5-tablet-only {
    --bulma-column-gap: 1.25rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-5-touch {
    --bulma-column-gap: 1.25rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-5-desktop {
    --bulma-column-gap: 1.25rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-5-desktop-only {
    --bulma-column-gap: 1.25rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-5-widescreen {
    --bulma-column-gap: 1.25rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-5-widescreen-only {
    --bulma-column-gap: 1.25rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-5-fullhd {
    --bulma-column-gap: 1.25rem;
  }
}
.columns.is-variable.is-6 {
  --bulma-column-gap: 1.5rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-6-mobile {
    --bulma-column-gap: 1.5rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-6-tablet {
    --bulma-column-gap: 1.5rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-6-tablet-only {
    --bulma-column-gap: 1.5rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-6-touch {
    --bulma-column-gap: 1.5rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-6-desktop {
    --bulma-column-gap: 1.5rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-6-desktop-only {
    --bulma-column-gap: 1.5rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-6-widescreen {
    --bulma-column-gap: 1.5rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-6-widescreen-only {
    --bulma-column-gap: 1.5rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-6-fullhd {
    --bulma-column-gap: 1.5rem;
  }
}
.columns.is-variable.is-7 {
  --bulma-column-gap: 1.75rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-7-mobile {
    --bulma-column-gap: 1.75rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-7-tablet {
    --bulma-column-gap: 1.75rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-7-tablet-only {
    --bulma-column-gap: 1.75rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-7-touch {
    --bulma-column-gap: 1.75rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-7-desktop {
    --bulma-column-gap: 1.75rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-7-desktop-only {
    --bulma-column-gap: 1.75rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-7-widescreen {
    --bulma-column-gap: 1.75rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-7-widescreen-only {
    --bulma-column-gap: 1.75rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-7-fullhd {
    --bulma-column-gap: 1.75rem;
  }
}
.columns.is-variable.is-8 {
  --bulma-column-gap: 2rem;
}
@media screen and (max-width: 768px) {
  .columns.is-variable.is-8-mobile {
    --bulma-column-gap: 2rem;
  }
}
@media screen and (min-width: 769px), print {
  .columns.is-variable.is-8-tablet {
    --bulma-column-gap: 2rem;
  }
}
@media screen and (min-width: 769px) and (max-width: 1023px) {
  .columns.is-variable.is-8-tablet-only {
    --bulma-column-gap: 2rem;
  }
}
@media screen and (max-width: 1023px) {
  .columns.is-variable.is-8-touch {
    --bulma-column-gap: 2rem;
  }
}
@media screen and (min-width: 1024px) {
  .columns.is-variable.is-8-desktop {
    --bulma-column-gap: 2rem;
  }
}
@media screen and (min-width: 1024px) and (max-width: 1215px) {
  .columns.is-variable.is-8-desktop-only {
    --bulma-column-gap: 2rem;
  }
}
@media screen and (min-width: 1216px) {
  .columns.is-variable.is-8-widescreen {
    --bulma-column-gap: 2rem;
  }
}
@media screen and (min-width: 1216px) and (max-width: 1407px) {
  .columns.is-variable.is-8-widescreen-only {
    --bulma-column-gap: 2rem;
  }
}
@media screen and (min-width: 1408px) {
  .columns.is-variable.is-8-fullhd {
    --bulma-column-gap: 2rem;
  }
}

/*# sourceMappingURL=columns-v2.css.map */
