:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.dropdown {
  --bulma-dropdown-menu-min-width: 12rem;
  --bulma-dropdown-content-background-color: var(--bulma-scheme-main);
  --bulma-dropdown-content-offset: 0.25rem;
  --bulma-dropdown-content-padding-bottom: 0.5rem;
  --bulma-dropdown-content-padding-top: 0.5rem;
  --bulma-dropdown-content-radius: var(--bulma-radius);
  --bulma-dropdown-content-shadow: var(--bulma-shadow);
  --bulma-dropdown-content-z: 20;
  --bulma-dropdown-item-h: var(--bulma-scheme-h);
  --bulma-dropdown-item-s: var(--bulma-scheme-s);
  --bulma-dropdown-item-l: var(--bulma-scheme-main-l);
  --bulma-dropdown-item-background-l: var(--bulma-scheme-main-l);
  --bulma-dropdown-item-background-l-delta: 0%;
  --bulma-dropdown-item-hover-background-l-delta: var(--bulma-hover-background-l-delta);
  --bulma-dropdown-item-active-background-l-delta: var(--bulma-active-background-l-delta);
  --bulma-dropdown-item-color-l: var(--bulma-text-strong-l);
  --bulma-dropdown-item-selected-h: var(--bulma-link-h);
  --bulma-dropdown-item-selected-s: var(--bulma-link-s);
  --bulma-dropdown-item-selected-l: var(--bulma-link-l);
  --bulma-dropdown-item-selected-background-l: var(--bulma-link-l);
  --bulma-dropdown-item-selected-color-l: var(--bulma-link-invert-l);
  --bulma-dropdown-divider-background-color: var(--bulma-border-weak);
}

.dropdown {
  display: inline-flex;
  position: relative;
  vertical-align: top;
}
.dropdown.is-active .dropdown-menu, .dropdown.is-hoverable:hover .dropdown-menu {
  display: block;
}
.dropdown.is-right .dropdown-menu {
  left: auto;
  right: 0;
}
.dropdown.is-up .dropdown-menu {
  bottom: 100%;
  padding-bottom: var(--bulma-dropdown-content-offset);
  padding-top: initial;
  top: auto;
}

.dropdown-menu {
  display: none;
  left: 0;
  min-width: var(--bulma-dropdown-menu-min-width);
  padding-top: var(--bulma-dropdown-content-offset);
  position: absolute;
  top: 100%;
  z-index: var(--bulma-dropdown-content-z);
}

.dropdown-content {
  background-color: var(--bulma-dropdown-content-background-color);
  border-radius: var(--bulma-dropdown-content-radius);
  box-shadow: var(--bulma-dropdown-content-shadow);
  padding-bottom: var(--bulma-dropdown-content-padding-bottom);
  padding-top: var(--bulma-dropdown-content-padding-top);
}

.dropdown-item {
  color: hsl(var(--bulma-dropdown-item-h), var(--bulma-dropdown-item-s), var(--bulma-dropdown-item-color-l));
  display: block;
  font-size: 0.875rem;
  line-height: 1.5;
  padding: 0.375rem 1rem;
}

a.dropdown-item,
button.dropdown-item {
  background-color: hsl(var(--bulma-dropdown-item-h), var(--bulma-dropdown-item-s), calc(var(--bulma-dropdown-item-background-l) + var(--bulma-dropdown-item-background-l-delta)));
  padding-inline-end: 3rem;
  text-align: inherit;
  white-space: nowrap;
  width: 100%;
}
a.dropdown-item:hover,
button.dropdown-item:hover {
  --bulma-dropdown-item-background-l-delta: var(--bulma-dropdown-item-hover-background-l-delta);
  --bulma-dropdown-item-border-l-delta: var(--bulma-dropdown-item-hover-border-l-delta);
}
a.dropdown-item:active,
button.dropdown-item:active {
  --bulma-dropdown-item-background-l-delta: var(--bulma-dropdown-item-active-background-l-delta);
  --bulma-dropdown-item-border-l-delta: var(--bulma-dropdown-item-active-border-l-delta);
}
a.dropdown-item.is-active, a.dropdown-item.is-selected,
button.dropdown-item.is-active,
button.dropdown-item.is-selected {
  --bulma-dropdown-item-h: var(--bulma-dropdown-item-selected-h);
  --bulma-dropdown-item-s: var(--bulma-dropdown-item-selected-s);
  --bulma-dropdown-item-l: var(--bulma-dropdown-item-selected-l);
  --bulma-dropdown-item-background-l: var(--bulma-dropdown-item-selected-background-l);
  --bulma-dropdown-item-color-l: var(--bulma-dropdown-item-selected-color-l);
}

.dropdown-divider {
  background-color: var(--bulma-dropdown-divider-background-color);
  border: none;
  display: block;
  height: 1px;
  margin: 0.5rem 0;
}

/*# sourceMappingURL=dropdown.css.map */
