.is-gapless {
  gap: 0 !important;
}

.is-gap-0 {
  gap: 0rem !important;
}

.is-gap-0\.5 {
  gap: 0.25rem !important;
}

.is-gap-1 {
  gap: 0.5rem !important;
}

.is-gap-1\.5 {
  gap: 0.75rem !important;
}

.is-gap-2 {
  gap: 1rem !important;
}

.is-gap-2\.5 {
  gap: 1.25rem !important;
}

.is-gap-3 {
  gap: 1.5rem !important;
}

.is-gap-3\.5 {
  gap: 1.75rem !important;
}

.is-gap-4 {
  gap: 2rem !important;
}

.is-gap-4\.5 {
  gap: 2.25rem !important;
}

.is-gap-5 {
  gap: 2.5rem !important;
}

.is-gap-5\.5 {
  gap: 2.75rem !important;
}

.is-gap-6 {
  gap: 3rem !important;
}

.is-gap-6\.5 {
  gap: 3.25rem !important;
}

.is-gap-7 {
  gap: 3.5rem !important;
}

.is-gap-7\.5 {
  gap: 3.75rem !important;
}

.is-gap-8 {
  gap: 4rem !important;
}

.is-column-gap-0 {
  column-gap: 0rem !important;
}

.is-column-gap-0\.5 {
  column-gap: 0.25rem !important;
}

.is-column-gap-1 {
  column-gap: 0.5rem !important;
}

.is-column-gap-1\.5 {
  column-gap: 0.75rem !important;
}

.is-column-gap-2 {
  column-gap: 1rem !important;
}

.is-column-gap-2\.5 {
  column-gap: 1.25rem !important;
}

.is-column-gap-3 {
  column-gap: 1.5rem !important;
}

.is-column-gap-3\.5 {
  column-gap: 1.75rem !important;
}

.is-column-gap-4 {
  column-gap: 2rem !important;
}

.is-column-gap-4\.5 {
  column-gap: 2.25rem !important;
}

.is-column-gap-5 {
  column-gap: 2.5rem !important;
}

.is-column-gap-5\.5 {
  column-gap: 2.75rem !important;
}

.is-column-gap-6 {
  column-gap: 3rem !important;
}

.is-column-gap-6\.5 {
  column-gap: 3.25rem !important;
}

.is-column-gap-7 {
  column-gap: 3.5rem !important;
}

.is-column-gap-7\.5 {
  column-gap: 3.75rem !important;
}

.is-column-gap-8 {
  column-gap: 4rem !important;
}

.is-row-gap-0 {
  row-gap: 0rem !important;
}

.is-row-gap-0\.5 {
  row-gap: 0.25rem !important;
}

.is-row-gap-1 {
  row-gap: 0.5rem !important;
}

.is-row-gap-1\.5 {
  row-gap: 0.75rem !important;
}

.is-row-gap-2 {
  row-gap: 1rem !important;
}

.is-row-gap-2\.5 {
  row-gap: 1.25rem !important;
}

.is-row-gap-3 {
  row-gap: 1.5rem !important;
}

.is-row-gap-3\.5 {
  row-gap: 1.75rem !important;
}

.is-row-gap-4 {
  row-gap: 2rem !important;
}

.is-row-gap-4\.5 {
  row-gap: 2.25rem !important;
}

.is-row-gap-5 {
  row-gap: 2.5rem !important;
}

.is-row-gap-5\.5 {
  row-gap: 2.75rem !important;
}

.is-row-gap-6 {
  row-gap: 3rem !important;
}

.is-row-gap-6\.5 {
  row-gap: 3.25rem !important;
}

.is-row-gap-7 {
  row-gap: 3.5rem !important;
}

.is-row-gap-7\.5 {
  row-gap: 3.75rem !important;
}

.is-row-gap-8 {
  row-gap: 4rem !important;
}

/*# sourceMappingURL=gap.css.map */
