:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.media:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

.media {
  --bulma-media-border-color: hsla(var(--bulma-scheme-h), var(--bulma-scheme-s), var(--bulma-border-l), 0.5);
  --bulma-media-border-size: 1px;
  --bulma-media-spacing: 1rem;
  --bulma-media-spacing-large: 1.5rem;
  --bulma-media-content-spacing: 0.75rem;
  --bulma-media-level-1-spacing: 0.75rem;
  --bulma-media-level-1-content-spacing: 0.5rem;
  --bulma-media-level-2-spacing: 0.5rem;
  align-items: flex-start;
  display: flex;
  text-align: inherit;
}
.media .content:not(:last-child) {
  margin-bottom: var(--bulma-media-content-spacing);
}
.media .media {
  border-top-color: var(--bulma-media-border-color);
  border-top-style: solid;
  border-top-width: var(--bulma-media-border-size);
  display: flex;
  padding-top: var(--bulma-media-level-1-spacing);
}
.media .media .content:not(:last-child),
.media .media .control:not(:last-child) {
  margin-bottom: var(--bulma-media-level-1-content-spacing);
}
.media .media .media {
  padding-top: var(--bulma-media-level-2-spacing);
}
.media .media .media + .media {
  margin-top: var(--bulma-media-level-2-spacing);
}
.media + .media {
  border-top-color: var(--bulma-media-border-color);
  border-top-style: solid;
  border-top-width: var(--bulma-media-border-size);
  margin-top: var(--bulma-media-spacing);
  padding-top: var(--bulma-media-spacing);
}
.media.is-large + .media {
  margin-top: var(--bulma-media-spacing-large);
  padding-top: var(--bulma-media-spacing-large);
}

.media-left,
.media-right {
  flex-basis: auto;
  flex-grow: 0;
  flex-shrink: 0;
}

.media-left {
  margin-inline-end: var(--bulma-media-spacing);
}

.media-right {
  margin-inline-start: var(--bulma-media-spacing);
}

.media-content {
  flex-basis: auto;
  flex-grow: 1;
  flex-shrink: 1;
  text-align: inherit;
}

@media screen and (max-width: 768px) {
  .media-content {
    overflow-x: auto;
  }
}

/*# sourceMappingURL=media.css.map */
