.section {
  --bulma-section-padding: 3rem 1.5rem;
  --bulma-section-padding-desktop: 3rem 3rem;
  --bulma-section-padding-medium: 9rem 4.5rem;
  --bulma-section-padding-large: 18rem 6rem;
  padding: var(--bulma-section-padding);
}
@media screen and (min-width: 1024px) {
  .section {
    padding: var(--bulma-section-padding-desktop);
  }
  .section.is-medium {
    padding: var(--bulma-section-padding-medium);
  }
  .section.is-large {
    padding: var(--bulma-section-padding-large);
  }
}
.section.is-fullheight {
  min-height: 100vh;
}

/*# sourceMappingURL=section.css.map */
