:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.tabs:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

.tabs {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.tabs {
  --bulma-tabs-border-bottom-color: var(--bulma-border);
  --bulma-tabs-border-bottom-style: solid;
  --bulma-tabs-border-bottom-width: 1px;
  --bulma-tabs-link-color: var(--bulma-text);
  --bulma-tabs-link-hover-border-bottom-color: var(--bulma-text-strong);
  --bulma-tabs-link-hover-color: var(--bulma-text-strong);
  --bulma-tabs-link-active-border-bottom-color: var(--bulma-link-text);
  --bulma-tabs-link-active-color: var(--bulma-link-text);
  --bulma-tabs-link-padding: 0.5em 1em;
  --bulma-tabs-boxed-link-radius: var(--bulma-radius);
  --bulma-tabs-boxed-link-hover-background-color: var(--bulma-background);
  --bulma-tabs-boxed-link-hover-border-bottom-color: var(--bulma-border);
  --bulma-tabs-boxed-link-active-background-color: var(--bulma-scheme-main);
  --bulma-tabs-boxed-link-active-border-color: var(--bulma-border);
  --bulma-tabs-boxed-link-active-border-bottom-color: transparent;
  --bulma-tabs-toggle-link-border-color: var(--bulma-border);
  --bulma-tabs-toggle-link-border-style: solid;
  --bulma-tabs-toggle-link-border-width: 1px;
  --bulma-tabs-toggle-link-hover-background-color: var(--bulma-background);
  --bulma-tabs-toggle-link-hover-border-color: var(--bulma-border-hover);
  --bulma-tabs-toggle-link-radius: var(--bulma-radius);
  --bulma-tabs-toggle-link-active-background-color: var(--bulma-link);
  --bulma-tabs-toggle-link-active-border-color: var(--bulma-link);
  --bulma-tabs-toggle-link-active-color: var(--bulma-link-invert);
}

.tabs {
  -webkit-overflow-scrolling: touch;
  align-items: stretch;
  display: flex;
  font-size: var(--bulma-size-normal);
  justify-content: space-between;
  overflow: hidden;
  overflow-x: auto;
  white-space: nowrap;
}
.tabs a {
  align-items: center;
  border-bottom-color: var(--bulma-tabs-border-bottom-color);
  border-bottom-style: var(--bulma-tabs-border-bottom-style);
  border-bottom-width: var(--bulma-tabs-border-bottom-width);
  color: var(--bulma-tabs-link-color);
  display: flex;
  justify-content: center;
  margin-bottom: calc(-1 * var(--bulma-tabs-border-bottom-width));
  padding: var(--bulma-tabs-link-padding);
  transition-duration: var(--bulma-duration);
  transition-property: background-color, border-color, color;
  vertical-align: top;
}
.tabs a:hover {
  border-bottom-color: var(--bulma-tabs-link-hover-border-bottom-color);
  color: var(--bulma-tabs-link-hover-color);
}
.tabs li {
  display: block;
}
.tabs li.is-active a {
  border-bottom-color: var(--bulma-tabs-link-active-border-bottom-color);
  color: var(--bulma-tabs-link-active-color);
}
.tabs ul {
  align-items: center;
  border-bottom-color: var(--bulma-tabs-border-bottom-color);
  border-bottom-style: var(--bulma-tabs-border-bottom-style);
  border-bottom-width: var(--bulma-tabs-border-bottom-width);
  display: flex;
  flex-grow: 1;
  flex-shrink: 0;
  justify-content: flex-start;
}
.tabs ul.is-left {
  padding-right: 0.75em;
}
.tabs ul.is-center {
  flex: none;
  justify-content: center;
  padding-left: 0.75em;
  padding-right: 0.75em;
}
.tabs ul.is-right {
  justify-content: flex-end;
  padding-left: 0.75em;
}
.tabs .icon:first-child {
  margin-inline-end: 0.5em;
}
.tabs .icon:last-child {
  margin-inline-start: 0.5em;
}
.tabs.is-centered ul {
  justify-content: center;
}
.tabs.is-right ul {
  justify-content: flex-end;
}
.tabs.is-boxed a {
  border: 1px solid transparent;
  border-start-start-radius: var(--bulma-tabs-boxed-link-radius);
  border-start-end-radius: var(--bulma-tabs-boxed-link-radius);
}
.tabs.is-boxed a:hover {
  background-color: var(--bulma-tabs-boxed-link-hover-background-color);
  border-bottom-color: var(--bulma-tabs-boxed-link-hover-border-bottom-color);
}
.tabs.is-boxed li.is-active a {
  background-color: var(--bulma-tabs-boxed-link-active-background-color);
  border-color: var(--bulma-tabs-boxed-link-active-border-color);
  border-bottom-color: var(--bulma-tabs-boxed-link-active-border-bottom-color) !important;
}
.tabs.is-fullwidth li {
  flex-grow: 1;
  flex-shrink: 0;
}
.tabs.is-toggle a {
  border-color: var(--bulma-tabs-toggle-link-border-color);
  border-style: var(--bulma-tabs-toggle-link-border-style);
  border-width: var(--bulma-tabs-toggle-link-border-width);
  margin-bottom: 0;
  position: relative;
}
.tabs.is-toggle a:hover {
  background-color: var(--bulma-tabs-toggle-link-hover-background-color);
  border-color: var(--bulma-tabs-toggle-link-hover-border-color);
  z-index: 2;
}
.tabs.is-toggle li + li {
  margin-inline-start: calc(-1 * var(--bulma-tabs-toggle-link-border-width));
}
.tabs.is-toggle li:first-child a {
  border-start-start-radius: var(--bulma-tabs-toggle-link-radius);
  border-end-start-radius: var(--bulma-tabs-toggle-link-radius);
}
.tabs.is-toggle li:last-child a {
  border-start-end-radius: var(--bulma-tabs-toggle-link-radius);
  border-end-end-radius: var(--bulma-tabs-toggle-link-radius);
}
.tabs.is-toggle li.is-active a {
  background-color: var(--bulma-tabs-toggle-link-active-background-color);
  border-color: var(--bulma-tabs-toggle-link-active-border-color);
  color: var(--bulma-tabs-toggle-link-active-color);
  z-index: 1;
}
.tabs.is-toggle ul {
  border-bottom: none;
}
.tabs.is-toggle.is-toggle-rounded li:first-child a {
  border-start-start-radius: var(--bulma-radius-rounded);
  border-end-start-radius: var(--bulma-radius-rounded);
  padding-inline-start: 1.25em;
}
.tabs.is-toggle.is-toggle-rounded li:last-child a {
  border-start-end-radius: var(--bulma-radius-rounded);
  border-end-end-radius: var(--bulma-radius-rounded);
  padding-inline-end: 1.25em;
}
.tabs.is-small {
  font-size: var(--bulma-size-small);
}
.tabs.is-medium {
  font-size: var(--bulma-size-medium);
}
.tabs.is-large {
  font-size: var(--bulma-size-large);
}

/*# sourceMappingURL=tabs.css.map */
