@charset "UTF-8";
:root {
  --bulma-control-radius: var(--bulma-radius);
  --bulma-control-radius-small: var(--bulma-radius-small);
  --bulma-control-border-width: 1px;
  --bulma-control-height: 2.5em;
  --bulma-control-line-height: 1.5;
  --bulma-control-padding-vertical: calc(0.5em - 1px);
  --bulma-control-padding-horizontal: calc(0.75em - 1px);
  --bulma-control-size: var(--bulma-size-normal);
  --bulma-control-focus-shadow-l: 50%;
}

.breadcrumb:not(:last-child) {
  margin-bottom: var(--bulma-block-spacing);
}

.breadcrumb {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}

.breadcrumb {
  --bulma-breadcrumb-item-color: var(--bulma-link-text);
  --bulma-breadcrumb-item-hover-color: var(--bulma-link-text-hover);
  --bulma-breadcrumb-item-active-color: var(--bulma-link-text-active);
  --bulma-breadcrumb-item-padding-vertical: 0;
  --bulma-breadcrumb-item-padding-horizontal: 0.75em;
  --bulma-breadcrumb-item-separator-color: var(--bulma-border);
}

.breadcrumb {
  font-size: var(--bulma-size-normal);
  white-space: nowrap;
}
.breadcrumb a {
  align-items: center;
  color: var(--bulma-breadcrumb-item-color);
  display: flex;
  justify-content: center;
  padding: var(--bulma-breadcrumb-item-padding-vertical) var(--bulma-breadcrumb-item-padding-horizontal);
}
.breadcrumb a:hover {
  color: var(--bulma-breadcrumb-item-hover-color);
}
.breadcrumb li {
  align-items: center;
  display: flex;
}
.breadcrumb li:first-child a {
  padding-inline-start: 0;
}
.breadcrumb li.is-active a {
  color: var(--bulma-breadcrumb-item-active-color);
  cursor: default;
  pointer-events: none;
}
.breadcrumb li + li::before {
  color: var(--bulma-breadcrumb-item-separator-color);
  content: "/";
}
.breadcrumb ul,
.breadcrumb ol {
  align-items: flex-start;
  display: flex;
  flex-wrap: wrap;
  justify-content: flex-start;
}
.breadcrumb .icon:first-child {
  margin-inline-end: 0.5em;
}
.breadcrumb .icon:last-child {
  margin-inline-start: 0.5em;
}
.breadcrumb.is-centered ol,
.breadcrumb.is-centered ul {
  justify-content: center;
}
.breadcrumb.is-right ol,
.breadcrumb.is-right ul {
  justify-content: flex-end;
}
.breadcrumb.is-small {
  font-size: var(--bulma-size-small);
}
.breadcrumb.is-medium {
  font-size: var(--bulma-size-medium);
}
.breadcrumb.is-large {
  font-size: var(--bulma-size-large);
}
.breadcrumb.has-arrow-separator li + li::before {
  content: "→";
}
.breadcrumb.has-bullet-separator li + li::before {
  content: "•";
}
.breadcrumb.has-dot-separator li + li::before {
  content: "·";
}
.breadcrumb.has-succeeds-separator li + li::before {
  content: "≻";
}

/*# sourceMappingURL=breadcrumb.css.map */
